@@ -23,11 +23,37 @@ code is being changed.
 
 =head1 VERSION
 
-Version 1.0.3
+Version 1.0.4
 
 =cut
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.4';
+
+
+=head1 CONFIGURATION OPTIONS
+
+This plugin supports the following options in the main section of your
+C<.githooksrc> file.
+
+	project_prefixes = OPS, DEV
+	extract_ticket_id_from_commit = /^($project_prefixes-\d+|--): /
+
+
+=head2 project_prefixes
+
+A comma-separated list of project prefixes, in case you want to use this in
+C<extract_ticket_id_from_commit> or C<extract_ticket_id_from_branch>.
+
+	project_prefixes = OPS, DEV
+
+
+=head2 extract_ticket_id_from_commit
+
+A regular expression with _one_ capturing group that will be applied to the
+first line of a commit message to extract the ticket ID referenced, if there is
+one.
+
+	extract_ticket_id_from_commit = /^($project_prefixes-\d+|--): /
 
 
 =head1 METHODS
@@ -106,7 +132,7 @@ C<< <aubertg at cpan.org> >>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2013-2014 Guillaume Aubert.
+Copyright 2013-2015 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
